@@ -7,10 +7,24 @@ tframe.zoo <- function (x) {
   }
 
 tfUnSet.zoo <- function(x)      {zoo:::coredata(x)}
-tfSet.zootframe <- function(value, x) { 
+tfSet.zootframe <- function(value, x){ 
   if(Tobs(value) != Tobs(x)) stop("number of Tobs of observations must correspond to number of Tobs indicated by tframe.")
   class(value) <- class(value)[class(value) != "zootframe"]
-  r <- zoo:::zoo(x, value) 
+  r <- zoo:::zoo(x, order.by = value) 
+  seriesNames(r) <- seriesNames(x)
+  r
+  }
+
+tfSet.Date    <- function(value, x){ 
+  if(Tobs(value) != Tobs(x)) stop("number of Tobs of observations must correspond to number of Tobs indicated by tframe.")
+  r <- zoo:::zoo(x, order.by = value) 
+  seriesNames(r) <- seriesNames(x)
+  r
+  }
+
+tfSet.POSIXct <- function(value, x){ 
+  if(Tobs(value) != Tobs(x)) stop("number of Tobs of observations must correspond to number of Tobs indicated by tframe.")
+  r <- zoo:::zoo(x, order.by = value) 
   seriesNames(r) <- seriesNames(x)
   r
   }
